@@ -9,9 +9,9 @@ data(mouse_snps)
 snps <- mouse_snps[1:500]
 
 test_that("nboot = 0 works", {
-    expect_equal(r2_hf(msats,  nboot_loci = 0, type = "msats")$r2_hf_full, 0.2797, 
+    expect_equal(r2_hf(msats, type = "msats")$r2_hf_full, 0.2797, 
                  tolerance = 0.001)
-    expect_equal(r2_hf(snps,  nboot_loci = 0, type = "snps")$r2_hf_full, 0.6698, 
+    expect_equal(r2_hf(snps, type = "snps")$r2_hf_full, 0.6698, 
                  tolerance = 0.001)
 })
 
@@ -23,9 +23,9 @@ test_that("nboot = 0 works", {
 # })
 
 test_that("Matrix input works", {
-    expect_equal(r2_hf(as.matrix(msats),nboot_loci = 0, type = "msats")$r2_hf_full, 
+    expect_equal(r2_hf(as.matrix(msats),type = "msats")$r2_hf_full, 
                  0.2797, tolerance = 0.001)
-    expect_equal(r2_hf(as.matrix(snps),  nboot_loci = 0, type = "snps")$r2_hf_full, 
+    expect_equal(r2_hf(as.matrix(snps), type = "snps")$r2_hf_full, 
                  0.6698, tolerance = 0.001)
 })
 
